==> FedTools-0.0.1.tar.gz: FedTools-0.0.1/README.md <==
# FedTools

An open source Python library for the scraping of Federal Reserve data.

By default, all modules within FedTools use 10 threads to increase scraping speed. By default, the Output is a 
Pandas DataFrame, indexed by release date of the materials. Additional serialised storage methods are optional.

## Installation

From Command Line:
```
$ python FedMinutes.py
```
Saves a Pickled Pandas DataFrame 'dataset.pkl', which contains all Meeting Minutes within search range, indexed by Date.

From Python:
```
pip install FedTools
from FedTools import MonetaryPolicyCommittee
```

## Usage

From Command Line:
```
$ python FedMinutes.py
```
Saves a Pickled Pandas DataFrame 'dataset.pkl', which contains all Meeting Minutes within search range, indexed by Date.

From Python:
```
pip install FedTools
from FedTools import MonetaryPolicyCommittee
dataset = MonetaryPolicyCommittee().find_statements()

MonetaryPolicyCommittee().pickle_data("DIRECTORY")
```
Returns a Pandas DataFrame 'dataset', which contains all Meeting Minutes, indexed by Date and a '.pkl' file saved within "DIRECTORY".

To edit input default arguments:
```sh
monetary_policy = MonetaryPolicyCommittee(
            main_url = 'https://www.federalreserve.gov', 
            calendar_url = 'https://www.federalreserve.gov/monetarypolicy/fomccalendars.htm',
            historical_split = 2014,
            verbose = True,
            max_threads = 10)
            
dataset = monetary_policy.find_statements()

# serialise, save to "DIRECTORY":
monetary_policy.pickle_data("DIRECTORY")
```

All parameters above are optional, with a short explanation of each parameter outlined below:

| Argument | Description |
| ------ | --------- |
| main_url | Federal Reserve Open Monetary Policy (FOMC) website URL. (str) |
| calendar_url | URL containing a list of FOMC Meeting dates. (str) |
| historical_split | year(s) considered as historical ([check here][hist]). (int)  |
| verbose | boolean determining printing during scraping. (bool) |
| thread_num | the number of threads to use for web scraping. (int)   |







   [hist]: <https://www.federalreserve.gov/monetarypolicy/fomc_historical_year.htm>

==> FedTools-0.0.2.tar.gz: FedTools-0.0.2/README.md <==
# FedTools

An open source Python library for the scraping of Federal Reserve data.

By default, all modules within FedTools use 10 threads to increase scraping speed. By default, the Output is a 
Pandas DataFrame, indexed by release date of the materials. Additional serialised storage methods are optional.

## Installation

From Python:
```
pip install FedTools

from FedTools import MonetaryPolicyCommittee
from FedTools import BeigeBooks
```

## Usage

From Python:
```
pip install FedTools
from FedTools import MonetaryPolicyCommittee
dataset = MonetaryPolicyCommittee().find_statements()

MonetaryPolicyCommittee().pickle_data("DIRECTORY")
```
Returns a Pandas DataFrame 'dataset', which contains all Meeting Minutes, indexed by Date and a '.pkl' file saved within "DIRECTORY".

```
pip install FedTools
from FedTools import BeigeBooks
dataset = beige_books.find_beige_books()

BeigeBooks().pickle_data("DIRECTORY")
```
Returns a Pandas DataFrame 'dataset', which contains all Beige Books, indexed by Date and a '.pkl' file saved within "DIRECTORY".




To edit input default arguments:
```sh
monetary_policy = MonetaryPolicyCommittee(
            main_url = 'https://www.federalreserve.gov', 
            calendar_url = 'https://www.federalreserve.gov/monetarypolicy/fomccalendars.htm',
            historical_split = 2014,
            verbose = True,
            thread_num = 10)
            
dataset = monetary_policy.find_statements()

# serialise, save to "DIRECTORY":
monetary_policy.pickle_data("DIRECTORY")


or

beige_books = BeigeBooks(
            main_url = 'https://www.federalreserve.gov', 
            beige_book_url='https://www.federalreserve.gov/monetarypolicy/beige-book-default.htm',
            historical_split = 2019,
            verbose = True,
            thread_num = 10)
            
            
dataset = BeigeBooks().find_beige_books()

# serialise, save to "DIRECTORY":
BeigeBooks().pickle_data("DIRECTORY")
```

All parameters above are optional, with a short explanation of each parameter outlined below:

| Argument | Description |
| ------ | --------- |
| main_url | Federal Reserve Open Monetary Policy (FOMC) website URL. (str) |
| calendar_url | URL containing a list of FOMC Meeting dates. (str) |
| historical_split | first year considered as historical ([Check Here for FOMC][hist] or [Check Here for Beige Books][hist1]). (int)  |
| verbose | boolean determining printing during scraping. (bool) |
| thread_num | the number of threads to use for web scraping. (int)   |







   [hist]: <https://www.federalreserve.gov/monetarypolicy/fomc_historical_year.htm>
   [hist1]: <https://www.federalreserve.gov/monetarypolicy/beige-book-archive.htm>
